"""remove table web_config_old

Revision ID: e69be63fc3b8
Revises: 1f86dd56d829
Create Date: 2021-11-02 11:44:47.061737

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e69be63fc3b8'
down_revision = '1f86dd56d829'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('web_config_old')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('web_config_old',
    sa.Column('config_id', sa.INTEGER(), nullable=False),
    sa.Column('head_title', sa.TEXT(), nullable=True),
    sa.Column('toolbar_title', sa.TEXT(), nullable=True),
    sa.Column('devtool_loadingstate', sa.BOOLEAN(), nullable=True),
    sa.Column('product_creation_dialog', sa.BOOLEAN(), nullable=True),
    sa.Column('product_update_dialog', sa.BOOLEAN(), nullable=True),
    sa.Column('product_deletion_dialog', sa.BOOLEAN(), nullable=True),
    sa.PrimaryKeyConstraint('config_id', name='pk_web_config')
    )
    # ### end Alembic commands ###
